@@ -2223,90 +2223,124 @@ class KrakenAPI(object):
 
         return currency, volume, fees, fees_maker
 
-    def add_standard_order(self, pair, type, ordertype, volume, price=None,
-                           price2=None, leverage=None, oflags=None, starttm=0,
-                           expiretm=0, userref=None, validate=True,
+    def add_standard_order(self, ordertype, type, pair, userref=None,
+                           volume=None, price=None, price2=None,
+                           trigger="last", leverage=None, oflags=None,
+                           timeinforce="GTC", starttm=0, expiretm=0,
                            close_ordertype=None, close_price=None,
-                           close_price2=None, otp=None,
-                           trading_agreement='agree'):
-        """Add a standard order.
-
-        Add a standard order and return an order description info and an array
-        of transaction ids for the order (if succesfull).
+                           close_price2=None, deadline=None, validate=True,
+                           otp=None):
+        """Place a new order.
 
         Parameters
         ----------
-        pair : str
-            Asset pair.
-
-        type : str
-            Type of order (buy/sell).
-
         ordertype : str
             Order type, one of:
-            market
-            limit (price = limit price)
-            stop-loss (price = stop loss price)
-            take-profit (price = take profit price)
-            stop-loss-profit (price = stop loss price, price2 = take profit
-                price)
-            stop-loss-profit-limit (price = stop loss price, price2 = take
-                profit price)
-            stop-loss-limit (price = stop loss trigger price, price2 =
-                triggered limit price)
-            take-profit-limit (price = take profit trigger price, price2 =
-                triggered limit price)
-            trailing-stop (price = trailing stop offset)
-            trailing-stop-limit (price = trailing stop offset, price2 =
-                triggered limit offset)
-            stop-loss-and-limit (price = stop loss price, price2 = limit price)
-            settle-position
+            ["market", "limit", "stop-loss", "take-profit", "stop-loss-limit",
+             "take-profit-limit", "settle-position"]
 
-        volume : str
-            Order volume in lots. For minimum order sizes, see
-            https://support.kraken.com/hc/en-us/articles/205893708
+        type : str
+            Order direction (buy/sell), one of:
+            ["buy", "sell"]
+
+        pair : str
+            Asset pair id or altname.
+
+        userref : int, optional (default=None)
+            User reference id.
+            userref is an optional user-specified integer id that can be
+            associated with any number of orders. Many clients choose a userref
+            corresponding to a unique integer id generated by their systems
+            (e.g. a timestamp). However, because we don't enforce uniqueness on
+            our side, it can also be used to easily group orders by pair, side,
+            strategy, etc. This allows clients to more readily cancel or query
+            information about orders in a particular group, with fewer API
+            calls by using userref instead of our txid, where supported.
+
+        volume : str, optional (default=None)
+            Order quantity in terms of the base asset
+            Note: Volume can be specified as 0 for closing margin orders to
+                  automatically fill the requisite quantity.
 
         price : str, optional (default=None)
-            Price (optional). Dependent upon ordertype
+            Price.
+            - Limit price for limit orders
+            - Trigger price for stop-loss, stop-loss-limit, take-profit and
+              take-profit-limit orders
 
         price2 : str, optional (default=None)
-            Secondary price (optional). Dependent upon ordertype
+            Secondary Price. Limit price for stop-loss-limit and
+            take-profit-limit orders.
+            Note: Either price or price2 can be preceded by +, -, or # to
+            specify the order price as an offset relative to the last traded
+            price. + adds the amount to, and - subtracts the amount from the
+            last traded price. # will either add or subtract the amount to the
+            last traded price, depending on the direction and order type used.
+            Relative prices can be suffixed with a % to signify the relative
+            amount as a percentage.
+
+        trigger : str, optional (default="last")
+            Price signal used to trigger stop-loss, stop-loss-limit,
+            take-profit and take-profit-limit orders. One of ["index", "last"].
+            Note: This trigger type will as well be used for associated
+            conditional close orders.
 
         leverage : str, optional (default=None)
-            Amount of leverage desired (optional). Default = none
+            Amount of leverage desired.
 
         oflags : str, optional (default=None)
             Comma delimited list of order flags:
-            viqc = volume in quote currency (not available for leveraged
-                orders)
-            fcib = prefer fee in base currency
-            fciq = prefer fee in quote currency
-            nompp = no market price protection
-            post = post only order (available when ordertype = limit)
+            - post post-only order (available when ordertype = limit)
+            - fcib prefer fee in base currency (default if selling)
+            - fciq prefer fee in quote currency (default if buying, mutually
+              exclusive with fcib)
+            - nompp disable market price protection for market orders
 
-        starttm : int, optional (default=None)
-            Scheduled start time:
+        timeinforce : str, optional (default="GTC")
+            One of ["GTC", "IOC", "GTD"].
+            Time-in-force of the order to specify how long it should remain in
+            the order book before being cancelled. GTC (Good-'til-cancelled) is
+            default if the parameter is omitted. IOC (immediate-or-cancel) will
+            immediately execute the amount possible and cancel any remaining
+            balance rather than resting in the book. GTD (good-'til-date), if
+            specified, must coincide with a desired expiretm.
+
+        starttm : int, optional (default=0)
+            Scheduled start time. Can be specified as an absolute timestamp or
+            as a number of seconds in the future.
             0 = now (default)
-            +<n> = schedule start time <n> seconds from now
+            +<n> = schedule start time seconds from now
             <n> = unix timestamp of start time
 
-        expiretm : int, optional (default=None)
-            Expiration time:
+        expiretm : int, optional (default=0)
+            Expiration time.
             0 = no expiration (default)
-            +<n> = expire <n> seconds from now
+            +<n> = expire seconds from now, minimum 5 seconds
             <n> = unix timestamp of expiration time
 
-        userref : int, optional (default=None)
-            User reference id.  32-bit signed number.
+        close_ordertype : str, optional (default=None)
+            Conditional close order type, one of ["limit", "stop-loss",
+            "take-profit", "stop-loss-limit", "take-profit-limit"].
+            Note: Conditional close orders are triggered by execution of the
+            primary order in the same quantity and opposite direction, but once
+            triggered are independent orders that may reduce or increase net
+            position.
+
+        close_price : str, optional (default=None)
+            Conditional close order price
+
+        close_price2 : str, optional (default=None)
+            Conditional close order price2
+
+        deadline : str, optional (default=None)
+            RFC3339 timestamp (e.g. 2021-04-01T00:18:45Z) after which the
+            matching engine should reject the new order request, in presence of
+            latency or order queueing. min now() + 2 seconds, max now() + 60
+            seconds.
 
         validate : bool, optional (default=True)
             Validate inputs only. Do not submit order (default).
 
-        optional closing order to add to system when order gets filled:
-            close[ordertype] = order type
-            close[price] = price
-            close[price2] = secondary price
-
         otp : str
             Two-factor password (if two-factor enabled, otherwise not required)
 
@@ -2315,8 +2349,7 @@ class KrakenAPI(object):
         res : dict
             res['descr'] = order description info
                 order = order description
-                close = conditional close order description (if conditional
-                    close set)
+                close = Conditional close order description, if applicable
             res['txid'] = array of transaction ids for order (if order was
                 added successfully)
 
@@ -2347,22 +2380,10 @@ class KrakenAPI(object):
 
         Notes
         -----
-        See get_tradable_asset_pairs for specifications on asset pair prices,
-        lots, and leverage.
 
-        Prices can be preceded by +, -, or # to signify the price as a relative
-        amount (with the exception of trailing stops, which are always
-        relative). + adds the amount to the current offered price. - subtracts
-        the amount from the current offered price. # will either add or
-        subtract the amount to the current offered price, depending on the type
-        and order type used. Relative prices can be suffixed with a % to
-        signify the relative amount as a percentage of the offered price.
-
-        For orders using leverage, 0 can be used for the volume to auto-fill
-        the volume needed to close out your position.
-
-        If you receive the error "EOrder:Trading agreement required", refer to
-        your API key management page for further details.
+        See get_tradable_asset_pairs for details on the available trading
+        pairs, their price and quantity precisions, order minimums, available
+        leverage, etc.
 
         """
 
